@@ -181,13 +181,13 @@ local function l_extract(self, nodups)
       end
    end
 
-   self.nodups = nodups
-   self.value  = myValue
-   self.type   = 'path'
-   self.tbl    = pathTbl
-   self.imin   = imin
-   self.imax   = imax
-   self.export = true
+   self.nodups    = nodups
+   self.value     = myValue
+   self.type      = 'path'
+   self.tbl       = pathTbl
+   self.imin      = imin
+   self.imax      = imax
+   self.export    = true
 end
 
 --------------------------------------------------------------------------
@@ -472,6 +472,18 @@ function M.append(self, value, nodups, priority)
    l_chkMP(name, value, adding)
 end
 
+function M.complete(self, args)
+   if (not args) then value = false end
+   self.type      = "complete"
+   self.value     = args
+end
+
+function M.uncomplete(self)
+   self.type      = "complete"
+   self.value     = false
+end
+
+
 --------------------------------------------------------------------------
 -- Set the environment variable to *value*
 -- @param self A Var object
