@@ -337,6 +337,16 @@ proc currentMode {} {
     return $mode
 }
 
+proc currentModeLmod {} {
+    global g_modeStack
+    set mode [lindex $g_modeStack end]
+    set returnVal "load"
+    if { $mode == "remove" } {
+	set returnVal "unload"
+    }
+    return $returnVal
+}
+
 proc pushMode {mode} {
     global g_modeStack
     lappend g_modeStack $mode
@@ -432,6 +442,7 @@ proc myBreak { args } {
        append msg $item
        append msg " "
     }
+    set msg [string trimright $msg]
     cmdargs "LmodBreak" $msg
 }
 
@@ -619,6 +630,21 @@ proc depends-on { args} {
     eval cmdargs "depends_on" $args
 }
 
+proc complete { shellName name args } {
+    global g_outputA
+    foreach arg $args {
+	set val [string trimright $arg "\r\n "]
+        set val [doubleQuoteEscaped $val]
+	lappend cmdArgsL $val
+    }
+    if {[info exists cmdArgsL]} {
+        set cmdArgs [join $cmdArgsL " "]
+	lappend g_outputA  "complete\(\"$shellName\",\"$name\",\"$cmdArgs\"\)\n"
+    } else {
+	lappend g_outputA  "complete\(\"$shellName\",\"$name\"\)\n"
+    }
+}
+
 proc my_exit { {code 1} } {
     eval cmdargs "os.exit" $code
 }
@@ -746,6 +772,7 @@ proc myPuts args {
 
     foreach {a b c} $args break
     set nonewline 0
+    set text "This string should never be seen!"
     switch [llength $args] {
         1 {
             set channel stdout
@@ -777,13 +804,16 @@ proc myPuts args {
         }
     }
     if { $putMode != "inHelp" } {
-        if { $nonewline == 0 } {
+        if { $nonewline == 0 && $channel  != "stdout" } {
             set text "$text\n"
         }
         set nonewline 0
         if { $channel == "stderr" } {
             set text "LmodMsgRaw(\[===\[$text\]===\])"
         } elseif { $channel == "stdout" } {
+	    set lmodMode [currentModeLmod]
+            set text "execute{cmd=\[===\[$text\]===\],modeA={\"$lmodMode\"}}"
+        } elseif { $channel == "prestdout" } {
             set text "io.stdout:write(\[===\[$text\]===\])"
         }
     }
@@ -950,7 +980,7 @@ proc execute-modulefile {modfile } {
     interp alias $child add-property   	 {} add-property
     interp alias $child always-load    	 {} always-load
     interp alias $child append-path    	 {} append-path
-    interp alias $child break       	 {} myBreak
+    interp alias $child complete       	 {} complete
     interp alias $child conflict       	 {} conflict
     interp alias $child depends-on     	 {} depends-on
     interp alias $child exit     	 {} my_exit
@@ -963,6 +993,7 @@ proc execute-modulefile {modfile } {
     interp alias $child module-info    	 {} module-info
     interp alias $child module-whatis  	 {} module-whatis
     interp alias $child myPuts         	 {} myPuts
+    interp alias $child myBreak      	 {} myBreak
     interp alias $child prepend-path   	 {} prepend-path
     interp alias $child prereq         	 {} prereq
     interp alias $child prereq-any     	 {} prereq-any
@@ -1012,6 +1043,16 @@ proc execute-modulefile {modfile } {
             setPutMode "normal"
         }
         if {$sourceFailed} {
+	    if { $sourceFailed == 4 || $errorMsg == {invoked "continue" outside of a loop}} {
+		set returnVal 0
+		showResults
+		return $returnVal
+	    } elseif { $sourceFailed == 3 || $errorMsg == {invoked "break" outside of a loop}} {
+		set returnVal 1
+		myBreak
+		showResults
+		return $returnVal
+	    }
             reportError $errorMsg
 	    set returnVal 1
         }
